scxpand.autoencoders.ae\_losses
===============================

.. automodule:: scxpand.autoencoders.ae_losses

   
   .. rubric:: Functions

   .. autosummary::
   
      compute_total_autoencoder_loss
      create_autoencoder_recon_loss_function
      should_use_soft_loss
   
   .. rubric:: Classes

   .. autosummary::
   
      MSELoss
      NB
      ZINBLoss
   